<?php

namespace Litecms\AssociateRank\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\AssociateRank\Models\AssociateRank;

class AssociateRankPolicy
{

    /**
     * Determine if the given user can view the associate_rank.
     *
     * @param UserPolicy $user
     * @param AssociateRank $associate_rank
     *
     * @return bool
     */
    public function view(UserPolicy $user, AssociateRank $associate_rank)
    {
        if ($user->canDo('associate_rank.associate_rank.view') && $user->isAdmin()) {
            return true;
        }

        return $associate_rank->user_id == user_id() && $associate_rank->user_type == user_type();
    }

    /**
     * Determine if the given user can create a associate_rank.
     *
     * @param UserPolicy $user
     * @param AssociateRank $associate_rank
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('associate_rank.associate_rank.create');
    }

    /**
     * Determine if the given user can update the given associate_rank.
     *
     * @param UserPolicy $user
     * @param AssociateRank $associate_rank
     *
     * @return bool
     */
    public function update(UserPolicy $user, AssociateRank $associate_rank)
    {
        if ($user->canDo('associate_rank.associate_rank.edit') && $user->isAdmin()) {
            return true;
        }

        return $associate_rank->user_id == user_id() && $associate_rank->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given associate_rank.
     *
     * @param UserPolicy $user
     * @param AssociateRank $associate_rank
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, AssociateRank $associate_rank)
    {
        return $associate_rank->user_id == user_id() && $associate_rank->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given associate_rank.
     *
     * @param UserPolicy $user
     * @param AssociateRank $associate_rank
     *
     * @return bool
     */
    public function verify(UserPolicy $user, AssociateRank $associate_rank)
    {
        if ($user->canDo('associate_rank.associate_rank.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given associate_rank.
     *
     * @param UserPolicy $user
     * @param AssociateRank $associate_rank
     *
     * @return bool
     */
    public function approve(UserPolicy $user, AssociateRank $associate_rank)
    {
        if ($user->canDo('associate_rank.associate_rank.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
