<?php

namespace Litecms\AssociateRank\Providers;

use Illuminate\Support\ServiceProvider;

class AssociateRankServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'associate_rank');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'associate_rank');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.associate_rank', function ($app) {
            return $this->app->make('Litecms\AssociateRank\AssociateRank');
        });

                // Bind AssociateRank to repository
        $this->app->bind(
            'Litecms\AssociateRank\Interfaces\AssociateRankRepositoryInterface',
            \Litecms\AssociateRank\Repositories\Eloquent\AssociateRankRepository::class
        );

        $this->app->register(\Litecms\AssociateRank\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\AssociateRank\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\AssociateRank\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.associate_rank'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/associate_rank.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/associate_rank')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/associate_rank')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
